@@ -1,7 +1,7 @@
-package Pinto::Remote::Config;
-
 # ABSTRACT: Internal configuration for Pinto::Remote
 
+package Pinto::Remote::Config;
+
 use Moose;
 use MooseX::Types::Moose qw(Maybe Str);
 
@@ -14,7 +14,7 @@ use namespace::autoclean;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.039'; # VERSION
+our $VERSION = '0.046'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -38,6 +38,13 @@ has password => (
     isa     => Maybe[Str],
 );
 
+
+has log_level => (
+    is      => 'ro',
+    isa     => Str,
+    default => 'warning',
+);
+
 #------------------------------------------------------------------------------
 
 around BUILDARGS => sub {
@@ -77,7 +84,7 @@ Pinto::Remote::Config - Internal configuration for Pinto::Remote
 
 =head1 VERSION
 
-version 0.039
+version 0.046
 
 =head1 AUTHOR
 
